# PIVA - Python Interactive Viewer for Arpes

GUI-application for data visualisation from Angle-Resolved 
Photoemission Spectroscopy (ARPES) experiments.

Please refer to the [documentation](https://piva.readthedocs.io/en/latest/) 
for more.
